import unittest

import tests.utils.user_util as user_util
import tests.utils.project_util as project_util
import tests.utils.work_util as work_util
import tests.utils.file_util as file_util
import vdcpy.file as vdc_file


class DownloadFileTest(unittest.TestCase):

    def setUp(self):
        # In case of the unittest user, project, work, and file already exist
        user_util.delete_unittest_users()
        project_util.delete_unittest_project()
        work_util.delete_unittest_works()
        file_util.delete_unittest_files()
        file_util.delete_test_file_and_temp_folder()

        # Create a unittest user
        user_util.add_unittest_user()
        # Create a unittest project
        project_util.add_unittest_project()
        # Create a unittest work
        work_util.add_unittest_work()
        # Create a unittest file
        file_util.make_temp_file_in_temp_folder()
        file_util.add_unittest_file()

    def test_success_download_file(self):
        """
        Test that a file can be downloaded and saved into a temp folder.
        """
        # Get the unittest file id
        file_list = vdc_file.get_files(name='unittest.txt')
        file_id = file_list[0]['id']
        # Download the file
        file_path = vdc_file.download_file(
            file_id=file_id,
            file_path='temp/unittest_download.txt'
        )
        # Check that the file was downloaded
        self.assertEqual('temp/unittest_download.txt', file_path)
        # Open the file and check that it contains the correct text
        with open(file_path, 'r') as file:
            self.assertEqual('test', file.read())


    def tearDown(self):
        user_util.delete_unittest_users()
        project_util.delete_unittest_project()
        work_util.delete_unittest_works()
        file_util.delete_unittest_files()
        file_util.delete_test_file_and_temp_folder()
