import unittest
from click.testing import CliRunner
import json


import vdcpy.link as vdc_link
import tests.utils.user_util as user_util
import tests.utils.project_util as project_util
import tests.utils.work_util as work_util
import tests.utils.link_util as link_util
import tests.utils.link_util as link_util


class DownloadLinkTest(unittest.TestCase):

    def setUp(self):
        # In case of the unittest user, project, work, and link already exist
        user_util.delete_unittest_users()
        project_util.delete_unittest_project()
        work_util.delete_unittest_works()
        link_util.delete_unittest_links()

        # Create a unittest user
        user_util.add_unittest_user()
        # Create a unittest project
        project_util.add_unittest_project()
        # Create a unittest work
        work_util.add_unittest_work()
        # Create a unittest link
        link_util.add_unittest_link()
        link_util.make_temp_directory()

    def test_success_download_link(self):
        """
        Test that a link can be downloaded and saved into a temp folder.
        """
        # Get the unittest link id
        link_list = vdc_link.get_links(name='unittest_link')
        link_id = link_list[0]['id']
        # Download the link
        link_path = vdc_link.download_link(
            link_id=link_id,
            file_path='temp/logo.png'
        )
        # Check that the link was downloaded
        self.assertEqual('temp/logo.png', link_path)


    def tearDown(self):
        user_util.delete_unittest_users()
        project_util.delete_unittest_project()
        work_util.delete_unittest_works()
        link_util.delete_unittest_links()
        link_util.delete_test_file_and_temp_folder()