import requests

import vdcpy.config as config

def get_projects(
    project_id=None, title=None, depositor_email=None, size=None,
    visibility=None):
    """
    Get a list of projects from the VDC API.
    """
    project_list = []
    query = f'{config.API_URL}/{config.PROJECT_NAMESPACE}'
    if project_id is not None:
        query += f'?id={project_id}'
    if title is not None:
        if project_id is None:
            query += f'?title={title}'
        else:
            query += f'&title={title}'
    if depositor_email is not None:
        if project_id is None and title is None:
            query += f'?depositor_email={depositor_email}'
        else:
            query += f'&depositor_email={depositor_email}'
    if size is not None:
        if project_id is None and title is None and depositor_email is None:
            query += f'?size={size}'
        else:
            query += f'&size={size}'
    if visibility is not None:
        if project_id is None and title is None and depositor_email is None \
            and size is None:
            query += f'?visibility={visibility}'
        else:
            query += f'&visibility={visibility}'
    response = requests.get(query)
    if response.status_code == 200:
        project_list = response.json()
    else:
        raise Exception(f'Error getting projects: {response.status_code}')
    return project_list


def add_project(project_info):
    """
    Add a project to the VDC API.
    """
    query = f'{config.API_URL}/{config.PROJECT_NAMESPACE}'
    response = requests.post(query, json=project_info)
    if response.status_code == 201:
        return response.json()
    else:
        raise Exception(
            f'Error adding project: {response.status_code} - {response.json()}'
        )


def update_project(project_id, project_info):
    """
    Update a project in the VDC API.
    """
    query = f'{config.API_URL}/{config.PROJECT_NAMESPACE}/{project_id}'
    response = requests.put(query, json=project_info)
    if response.status_code == 200:
        return response.json()
    else:
        raise Exception(f'Error updating project: {response.status_code}')


def delete_project(project_id):
    """
    Delete a project from the VDC API.
    """
    query = f'{config.API_URL}/{config.PROJECT_NAMESPACE}/{project_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting project: {response.status_code}')
