import requests

import vdcpy.config as config


def get_works(
    work_id=None, title=None, abstract=None, genre=None, visibility=None,
    project=None, created_by=None):
    """
    Get a list of works from the VDC API.
    """
    work_list = []
    query = f'{config.API_URL}/{config.WORK_NAMESPACE}'
    if work_id is not None:
        query += f'?id={work_id}'
    if title is not None:
        if work_id is None:
            query += f'?title={title}'
        else:
            query += f'&title={title}'
    if abstract is not None:
        if work_id is None and title is None:
            query += f'?abstract={abstract}'
        else:
            query += f'&abstract={abstract}'
    if genre is not None:
        if work_id is None and title is None and abstract is None:
            query += f'?genre={genre}'
        else:
            query += f'&genre={genre}'
    if visibility is not None:
        if work_id is None and title is None and abstract is None and genre is None:
            query += f'?visibility={visibility}'
        else:
            query += f'&visibility={visibility}'
    if project is not None:
        if work_id is None and title is None and abstract is None and genre is None and visibility is None:
            query += f'?project={project}'
        else:
            query += f'&project={project}'
    if created_by is not None:
        if work_id is None and title is None and abstract is None and genre is None and visibility is None and project is None:
            query += f'?created_by={created_by}'
        else:
            query += f'&created_by={created_by}'
    response = requests.get(query)
    if response.status_code == 200:
        work_list = response.json()
    else:
        raise Exception(f'Error getting works: {response.status_code}')
    return work_list


def add_work(work_info):
    """
    Add a work to the VDC API.
    """
    query = f'{config.API_URL}/{config.WORK_NAMESPACE}'
    response = requests.post(query, json=work_info)
    if response.status_code == 201:
        return response.json()
    else:
        raise Exception(
            f'Error adding work: {response.status_code} - {response.json()}'
        )


def update_work(work_id, work_info):
    """
    Update a work in the VDC API.
    """
    query = f'{config.API_URL}/{config.WORK_NAMESPACE}/{work_id}'
    response = requests.put(query, json=work_info)

    if response.status_code == 200:
        return response.json()
    else:
        raise Exception(
            f'Error updating work: {response.status_code} - {response.json()}'
        )


def delete_work(work_id):
    """
    Delete a work from the VDC API.
    """
    query = f'{config.API_URL}/{config.WORK_NAMESPACE}/{work_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting work: {response.status_code}')
